@@ -1,26 +1,18 @@
-import json
 import os
 import sys
-import tempfile
 from collections import defaultdict
 from enum import IntEnum
 from pathlib import Path
-from typing import Any
 from urllib.parse import urlparse
 
-import tiktoken
+from typing_extensions import Any
 
+from patchwork.common.utils import count_openai_tokens, open_with_chardet
 from patchwork.logger import logger
 from patchwork.step import Step
-
-from ...common.utils import open_with_chardet
-from .context_strategy.context_strategies import ContextStrategies
-
-_ENCODING = tiktoken.get_encoding("cl100k_base")
-
-
-def count_tokens(code: str):
-    return len(_ENCODING.encode(code))
+from patchwork.steps.ExtractCode.context_strategy.context_strategies import (
+    ContextStrategies,
+)
 
 
 def get_source_code_context(
@@ -36,7 +28,7 @@ def get_source_code_context(
 
         logger.info(f'"{context_strategy.__class__.__name__}" Context Strategy used: {context_start}, {context_end}')
         context = "".join(source_lines[context_start:context_end])
-        if count_tokens(context) <= context_token_length:
+        if count_openai_tokens(context) <= context_token_length:
             return context_start, context_end
 
     return None, None
@@ -246,7 +238,7 @@ def transform_sarif_results(
                 start = context_start if context_start is not None else start_line
                 end = context_end if context_end is not None else end_line
 
-                grouped_messages[(uri, start, end, source_code_context)].append(
+                grouped_messages[(file_path, start, end, source_code_context)].append(
                     result.get("message", {}).get("text", "")
                 )
 
@@ -258,7 +250,7 @@ def transform_sarif_results(
 
 
 class ExtractCode(Step):
-    required_keys = {"sarif_file_path"}
+    required_keys = {"sarif_values"}
 
     def __init__(self, inputs: dict):
         logger.info(f"Run started {self.__class__.__name__}")
@@ -266,11 +258,7 @@ class ExtractCode(Step):
         if not all(key in inputs.keys() for key in self.required_keys):
             raise ValueError(f'Missing required data: "{self.required_keys}"')
 
-        # Validate and set the SARIF file path
-        self.sarif_file_path = Path(inputs["sarif_file_path"])
-        if not self.sarif_file_path.exists() or not self.sarif_file_path.is_file():
-            raise ValueError(f'SARIF file path does not exist or is not a file: "{self.sarif_file_path}"')
-
+        self.sarif_data = inputs["sarif_values"]
         # Check and set number of lines to extract
         self.context_length = inputs.get("context_size", 1000)
         self.vulnerability_limit = inputs.get("vulnerability_limit", 10)
@@ -280,14 +268,10 @@ class ExtractCode(Step):
         self.extracted_code_contexts = []
 
     def run(self) -> dict:
-        # Load SARIF data
-        with open_with_chardet(self.sarif_file_path, "r") as file:
-            sarif_data = json.load(file)
-
         base_path = Path.cwd()
 
         grouped_messages = transform_sarif_results(
-            sarif_data, base_path, self.context_length, self.vulnerability_limit, self.severity_threshold
+            self.sarif_data, base_path, self.context_length, self.vulnerability_limit, self.severity_threshold
         )
 
         self.extracted_code_contexts = [
@@ -301,14 +285,9 @@ class ExtractCode(Step):
             for (file_path, start, end, context), msgs in grouped_messages.items()
         ]
 
-        # Save extracted data to JSON
-        output_file = Path(tempfile.mktemp(".json"))
-        with open(output_file, "w", encoding="utf-8") as f:
-            json.dump(self.extracted_code_contexts, f, indent=2)
-
         logger.info(f"Run completed {self.__class__.__name__}")
 
         return dict(
-            code_file=output_file,
+            files_to_patch=self.extracted_code_contexts,
             prompt_values=self.extracted_code_contexts,
         )
