@@ -2,14 +2,14 @@ from typing_extensions import Iterable, NotRequired, TypedDict
 
 
 class ExtractCodeInputs(TypedDict):
-    sarif_file_path: str
+    sarif_data: dict
     context_size: NotRequired[int]
     vulnerability_limit: NotRequired[int]
     severity: NotRequired[str]
 
 
 class ExtractCodeOutputs(TypedDict):
-    code_file: str
+    files_to_patch: Iterable["ExtractedCode"]
     prompt_values: Iterable["ExtractedCode"]
 
 
