@@ -1,5 +1,5 @@
 import atexit
-import os
+import json
 import shutil
 import subprocess
 import tempfile
@@ -106,7 +106,16 @@ class ScanDepscan(Step):
 
         p = subprocess.run(cmd, capture_output=True, text=True)
 
-        sbom_vdr_file_path = os.path.join(temp_file_path, sbom_vdr_file_name + ".vdr.json")
+        sbom_vdr_file_path = temp_file_path / f"{sbom_vdr_file_name}.vdr.json"
+        try:
+            with open(sbom_vdr_file_path, "r") as f:
+                sbom_values = json.load(f)
+        except json.JSONDecodeError as e:
+            logger.debug(e)
+            raise ValueError(f"Error reading SBOM VDR file from Depscan")
+        except FileNotFoundError as e:
+            logger.debug(e)
+            raise ValueError(f"SBOM VDR file not found from Depscan")
 
         logger.info(f"Run completed {self.__class__.__name__}")
-        return {"sbom_vdr_file_path": sbom_vdr_file_path}
+        return {"sbom_vdr_values": sbom_values}
